
if not IsNewState then
	-- io does not exist at the time this script usually gets called (i.e. when IsNewState is true), but if it gets called again
	-- at an unexpected time, io will probably exist by then
	io.stdout:write("Warning: stringidrevealer_register.lua called when IsNewState is not true\r\n" .. debug.traceback() .. "\r\n")
	io.stdout:flush()
	return
end

-- No registered global table yet? Wait for the next call, then
if not _G then
	return
end

local ScriptType = {
	Keybind = 0,
	Persist = 1,
	PostRequire = 2,
	Close = 3,
	PrioritizedPostRequire = 4
}

-- This priority setting behaves inversely to BLT's mod.txt priority setting
-- BLT Hook: The higher the priority value, the /sooner/ it runs (i.e. another mod with a smaller priority gets the final say)
-- Harfatus' Hook: The higher the priority value, the /later/ it runs (i.e. it gets the final say)
local priority = -10

if _G.StringIDRevealer_ModPath == nil then
	_G.StringIDRevealer_ModPath = "lib/Lua/StringIDRevealer/"
end

-- IMPORTANT: This requires at least version 3.2.1 of Harfatus' Hook (crashes on 3.2.0 or earlier versions)
-- Version 3.2.2 is available in HoxHud P9.1.7 at the following URL:
-- https://github.com/HoxHud/HoxHud-bin/blob/e5381df6c404b8410992dc17fba5a32b6ab69725/HoxHud%20P9.1.7%20Manual%20install.7z
-- Do not use version 3.2.3 (post-Crimefest 2015) as it fails to hook the required C++ functions
RegisterScript(StringIDRevealer_ModPath .. "localizationmanager.lua", ScriptType.PrioritizedPostRequire, "lib/managers/localizationmanager", priority)

-- https://msdn.microsoft.com/en-us/library/windows/desktop/dd375731(v=vs.85).aspx
-- VK_OEM_1 = ; key (US keyboard layout)
-- NOTE: GG Harfatus, this doesn't even work. You'll have to manually add it to the .yml config file instead
--RegisterScript(StringIDRevealer_ModPath .. "toggle.lua", ScriptType.Keybind, "VK_OEM_1")
